//      DSZ_LOG.FNC
//
//      This is a collection of function salts to add to your
//      protocol scripts that will add DSZ.LOG transfer information
//      to your Telix log if you are using one.  It will work with
//      ANY protocol that writes to the DSZLOG file as set in your
//      DOS environment, i.e.
//                      SET DSZLOG=C:\TELIX\DSZ.LOG
//      
//      Please read @GSZ.Slt, included in this archive, for a commented
//      example of a protocol script using these functions.  The protocol
//      scripts @HSLnk.Slt and @Moby.Slt also use these scripts, but are
//      not as fully commented as to their use.
//
//      For this to work correctly requires a few simple steps.
//
//      1. First of all you MUST define DSZ_Use as a GLOBAL variable
//      by inserting the statement
//
//      str DSZ_Use[65];
//
//      If you are using the upload file tagger in Telix 3.20, you should
//      add this line(if your protocol script has it already, make it GLOBAL).
//
//      str fbuf[12], fspec[17]="C:\TELIX\FILELIST";
//
//      add this BEFORE the start of your main section.
//
//      2. Within your main section you must insert these additional lines.
//
//      After any necessary steps to create your protocol command line,
//      but IMMEDIATELY BEFORE you execute the transfer, insert the
//      statements:
//
//      Check_Log();
//      int t, e; str tbuff[16]; t = timer_start(0);
//
//      IMMEDIATELY after the transfer returns, insert the lines:
//
//      e = timer_total(t); timer_free(0); time((e/10), tbuff);
//      Write_Log();
//      ustamp("++ Transfer time : ", 1, 0); ustamp(tbuff, 0, 1);
//
//      This will complete the Telix log entry.
//
//      3. Finally append the following four function salts to the end
//      of your protocol script.
//
//      That's All Folks!  Now the DSZ.LOG information will be entered into
//      your Telix log file, followed by an entry showing transfer time.
//
Check_Log () {    
    if (getenv("DSZLOG", DSZ_Use)) {     // Check for existence of the   //
        frename(DSZ_Use, "DSZLOG.ORG");  // DSZLOG Log File (from DOS)   //
        Open_DSZ_Log ();                 // Rename it to "DSZLOG.ORG"    //
     }                                   // and open a new one for this  //
     else                                // transfer...                  //
        prints("No DSZLOG File found !");// Otherwise print this message //
                                         // on the screen...             //
}
Write_Log () {
    if (getenv("DSZLOG", DSZ_Use)) {     // Check that log's still there //
        Transfer_to_Telix_Log();         // then move the information    //
        fdelete(DSZ_Use);                // into the Telix Log File and  //
        frename("DSZLOG.ORG", DSZ_Use);  // delete the new DSZLOG, and   //
       }                                 // finally restore orig DSZLOG  //
}
Open_DSZ_Log () {
         str Entry_ID[78], Entry_Stripe[78], Stripe[78];
         str Entry_Date[16], Entry_Time[16], DSZ_Log_File[65];
         int Loop, Open_File;
         getenv("DSZLOG",DSZ_Log_File);       // Check that log's still there //
         date(curtime(),Entry_Date);          // Put the date into Entry_Date //
         time(curtime(),Entry_Time);          // Put the time into Entry_Time //
         Stripe = "";
         for (Loop = 0; Loop < 78; ++Loop)
              strcat(Stripe, "");
//  This next test for download/upload is for NON-BATCH protocols!
//  if (_ext_filespec != "")
//  Using Telix's buildt-in Upload file tagger, and the '@' character as
//  the first character of the filename, use the following test.
    if (filefind (fspec,0,fbuf))
         { Entry_ID = "MobyTurbo U/L with "; } //  Create an Entry Divider ID  //
    else                                       //  using the protocol name
         { Entry_ID = "MobyTurbo D/L with "; }
         strcat(Entry_ID,_entry_name);        //  with the BBS name           //
         strcat(Entry_ID," (at ");
         strcat(Entry_ID,_entry_num);         //  and Phone Number            //
         strcat(Entry_ID,") begun on ");
         strcat(Entry_ID,Entry_Date);         //  and Date                    //
         strcat(Entry_ID," at ");
         strcat(Entry_ID,Entry_Time);         //  and Time                    //
         substr(Stripe,0,strlen(Entry_ID),Entry_Stripe);
         if ( (Open_File = fopen(DSZ_Log_File,"a")) == 0)
               prints("Couldn't open the Log File !");
         else {
               fputc(10,Open_File);           // Write the Divider ID to the  //
               fputs(Entry_ID,Open_File);     // new DSZLOG file...           //
               fputc(10,Open_File);
               fputs(Entry_Stripe,Open_File);
               fputs(Stripe,Open_File);
               fputc(10,Open_File);
               fclose(Open_File);
              }
}
Transfer_to_Telix_Log() {
         str DSZ_File[65], DSZ_Detail[255];
         int File_Handle;
         getenv("DSZLOG",DSZ_File);
         if ( (File_Handle = fopen(DSZ_File,"r")) != 0) { // If you can  //
               while (!feof(File_Handle)) {               // open the file   //
                     fgets(DSZ_Detail, 255, File_Handle); // for reading then//
                     ustamp(DSZ_Detail, 0, 1);            // read until the  //
                     DSZ_Detail = "";                     // "eof", putting  //
                      }                                   // the info into   //
               fclose(File_Handle);                       // the Telix Log   //
              }
}
